﻿using Syncfusion.DocIO;
using Syncfusion.DocIO.DLS;
using Syncfusion.Windows.Controls.RichTextBoxAdv;
using System;
using System.Collections.Generic;
using System.Data;
using System.IO;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using FormatType = Syncfusion.Windows.Controls.RichTextBoxAdv.FormatType;

namespace Sample
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        int imageCounter = 0;
        private InsertMergeFieldUI fieldUI;
        /// <summary>
        /// Constructor.
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
			richTextBoxAdv.Load(@"..\\..\\Sample\\Letter Formatting.doc");
            this.Unloaded += MainWindow_Unloaded;
            richTextBoxAdv.Focus();
            fieldUI = new InsertMergeFieldUI(richTextBoxAdv);
            fieldUI.InsertFieldButton.Click += InsertFieldButton_Click;
            fieldUI.CancelButton.Click += CancelButton_Click;
        }

        /// <summary>
        /// Called when mainwindow unloaded.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void MainWindow_Unloaded(object sender, RoutedEventArgs e)
        {
            this.Unloaded -= MainWindow_Unloaded;
            if (richTextBoxAdv != null)
            {
                richTextBoxAdv.Dispose();
                richTextBoxAdv = null;
            }
        }
        private void showInsertFieldUI_Click(object sender, RoutedEventArgs e)
        {
            if (fieldUI != null)
                fieldUI.Show();
            else
            {
                fieldUI = new InsertMergeFieldUI(richTextBoxAdv);
                fieldUI.Show();
            }
        }
        /// <summary>
        /// Called when the cancel button of Insert field is clicked.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void CancelButton_Click(object sender, RoutedEventArgs e)
        {
            fieldUI.Reset();
            fieldUI.Hide();
        }
        /// <summary>
        /// Called when the insert button of Insert field is clicked.
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void InsertFieldButton_Click(object sender, RoutedEventArgs e)
        {
            if (!string.IsNullOrEmpty(fieldUI.FieldName))
            {
                // Create word document(docio) instance.
                WordDocument document = new WordDocument();

                document.EnsureMinimal();

                //Sets page margins to the last section of the document

                document.LastSection.PageSetup.Margins.All = 72;

                //Appends text to the last paragraph.

                //Appends merge field to the last paragraph.

                document.LastParagraph.AppendField(fieldUI.FieldName, Syncfusion.DocIO.FieldType.FieldMergeField);

                DataObject data = new DataObject();

                // Extract the text data from document.
                string text = document.GetText();

                //Sets the text content to clipboard.
                data.SetText(text);

                Stream stream = new MemoryStream();
                // Saves the document as Rtf Stream.
                document.Save(stream, Syncfusion.DocIO.FormatType.Rtf);
                stream.Position = 0;
                // Reads the stream and assigned the string to RtfText property
                using (StreamReader reader = new StreamReader(stream))
                {
                    text = reader.ReadToEnd();
                }
                //Sets the rich text format content to clipboard.
                data.SetData(DataFormats.Rtf, text);

                try
                {
                    //set the dataobject to the clipboard
                    Clipboard.SetDataObject(data);
                }
                catch
                {
                    // Copying data to Clipboard can potentially fail - for example, if another application is holding Clipboard open.
                }
                // Hides the popup.
                fieldUI.Reset();
                fieldUI.Hide();
                // Move the focus.
                richTextBoxAdv.Focus();
                // Paste the field into SfRichTextBoxAdv at cursor position.
                SfRichTextBoxAdv.PasteCommand.Execute(null, richTextBoxAdv);
            }
            else
            {
                // Hides the popup.
                fieldUI.Reset();
                fieldUI.Hide();
                // Move the focus.
                richTextBoxAdv.Focus();
            }
        }
        /// <summary>
        /// Performs mail merge
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void do_mailMerge_Click(object sender, RoutedEventArgs e)
        {
            if (richTextBoxAdv.Document != null)
            {
                //Creates new memory stream.
                Stream ms = new MemoryStream();

                // Save the document of SfRichTextBoxAdv as docx stream. 
                richTextBoxAdv.Save(ms, Syncfusion.Windows.Controls.RichTextBoxAdv.FormatType.Docx);

            }
        }

        private void MailMerge_OnClick(object sender, RoutedEventArgs e)
        {
			Stream stream=new MemoryStream();
			richTextBoxAdv.Save(stream,FormatType.Docx);
			stream.Position = 0;
            
            // Open the docx stream.
            WordDocument document = new WordDocument(stream, Syncfusion.DocIO.FormatType.Docx);
            //Sets field names and field values
            string[] fieldNames = new string[] { "ContactName", "CompanyName", "Address", "City", "Region", "Country", "Phone", "Fax" };
            string[] fieldValues = new string[] { "Jones", "Syncfusion", "14, ES street", "NewYork", "USA","United States", "+12463583748", "FaxValue" };
            //Performs Mail merge
            document.MailMerge.Execute(fieldNames, fieldValues);

            //Saves the Word document
            MemoryStream memoryStream = new MemoryStream();
            document.Save(memoryStream, Syncfusion.DocIO.FormatType.Docx);
            document.Close();
            memoryStream.Position = 0;
            //Launch the Word document.
            richTextBoxAdv.Load(memoryStream, FormatType.Docx);


		}
       
    }
}
